from setuptools import setup
import os

# Carregar o conteúdo do arquivo README.md
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name='utils-pandas',
    version='0.0.2',
    description='Pacote Python destinado a criar novas funcionalidades para o Pandas',
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=['utils-pandas'],
    install_requires=[],
)



import json

def to_json(df):
    lista_dicionarios = df.to_dict(orient='records')
    json_data = json.dumps(lista_dicionarios, ensure_ascii=False)
    return json_data


def to_json_for_column(df, column=None):
    if column is None:
        column = df.columns[0]
    
    cols = df.columns.difference([column])
    d = (df.groupby(column)[cols]
            .apply(lambda x: x.to_dict('r'))
            .reset_index(name='dados')
            .to_dict(orient='records'))
    
    return d